/*jslint browser: true, regexp: true, plusplus: true*/
/*global define*/

define([
    'testsuite/qunit',
    'testsuite/qunit-helper',
    'testsuite/qunit-fixture!ckeditor/plugins/epimage/plugin-test',
    'jquery',
    'ckeditor/ckeditor',
    'ep/ui/editor',

    '$ready!'
    ], function (QUnit, helper, fixture, $, CKEDITOR) {

    'use strict';

    // CKEDITOR test workflow helper
    function cke_test(setfunction, testfunction) {
        var delay;

        // Wait for opening th editor
        setTimeout(function () {

            CKEDITOR.instances.uieditor_ckeditortestinstance.setData('');

            $('.cke_button__epimage').trigger('click');

            setTimeout(function () {

                QUnit.equal(
                    $('.fileManagerDialog').is(':visible'),
                    true,
                    'Filemanager opened'
                );

                $('.fileManagerDialog').data('uiUiDialog').close();

                // Call set
                setfunction();

                setTimeout(function () {

                    QUnit.equal(
                        $('.fileManagerDialog').is(':visible'),
                        false,
                        'Filemanager closed'
                    );

                    $('.cke_dialog_ui_button_ok span').trigger('click');

                    setTimeout(function () {
                        // Call test
                        testfunction(CKEDITOR.instances.uieditor_ckeditortestinstance.getData());
                    }, 400);

                }, 400);

            }, 1000);

        }, 1000);
    }

    QUnit.module("ckeditor/plugins/epimage", {
        setup: function () {
            fixture.init();

            // instantiate CKE
            this.editor = $('#uieditor_ckeditortestinstance')
                .uiEditor({
                    'name' : 'ckeditortestinstance',
                    'toolbar': 'Full'
                });
        },
        teardown: function () {
            fixture.destroy();

            $('.fileManagerDialog').remove();
        }
    });

    QUnit.asyncTest("basic image source test", 7 * 3, function () {

        helper.asyncTimeboxSeries(3000, function (done) {
            cke_test.call(this, function () {
                $('#' + $('.cke_required').filter('label:contains(URL)').attr('for')).val('foobar.png');
            }, function (data) {
                var expected = /<img alt="" src="foobar.png" \/>/;

                QUnit.ok(
                    data.search(expected) > -1,
                    'image source is set'
                );

                done();
            });


        }, function (done) {
            cke_test.call(this, function () {
                $('#' + $('.cke_required').filter('label:contains(URL)').attr('for')).val('foobar.png');
                $('.cke_dialog_contents .cke_dialog_page_contents tbody:first').children('tr:eq(1)').find('input').val('look at this beautfiful foo');
            }, function (data) {
                var expected = /<img alt="look at this beautfiful foo" src="foobar.png" \/>/;

                QUnit.ok(
                    data.search(expected) > -1,
                    'alt attribute set correctly'
                );

                done();
            });
        }, function (done) {
            cke_test.call(this, function () {
                $('#' + $('.cke_required').filter('label:contains(URL)').attr('for')).val('foobar.png');
                $('.cke_dialog_contents .cke_dialog_page_contents tbody:first').children('tr:eq(2)').find('input').val('barfoo');
            }, function (data) {
                var expected = /<img alt="" src="foobar.png" title="barfoo" \/>/;

                QUnit.ok(
                    data.search(expected) > -1,
                    'title attribute set correctly'
                );

                done();
            });
        }, function (done) {
            cke_test.call(this, function () {
                $('#' + $('.cke_required').filter('label:contains(URL)').attr('for')).val('foobar.png');
                $('.cke_dialog_contents .cke_dialog_page_contents tbody:first').children('tr:eq(3)').find('input:eq(0)').val('500');
                $('.cke_dialog_contents .cke_dialog_page_contents tbody:first').children('tr:eq(3)').find('input:eq(1)').val('300');
            }, function (data) {
                var expected = /<img alt="" src="foobar.png" style="width: 500px; height: 300px; ?" \/>/;

                QUnit.ok(
                    data.search(expected) > -1,
                    'width and height attribute set correctly'
                );

                done();
            });
        }, function (done) {
            cke_test.call(this, function () {
                $('#' + $('.cke_required').filter('label:contains(URL)').attr('for')).val('foobar.png');
                $('.cke_dialog_contents .cke_dialog_page_contents tbody:first').children('tr:eq(3)').find('input:eq(2)').val('1');
            }, function (data) {
                var expected = /<img alt="" src="foobar.png" style="border-width: 1px; border-style: solid; ?" \/>/;

                QUnit.ok(
                    data.search(expected) > -1,
                    'border attribute set correctly'
                );

                done();
            });
        }, function (done) {
            cke_test.call(this, function () {
                $('#' + $('.cke_required').filter('label:contains(URL)').attr('for')).val('foobar.png');
                $('.cke_dialog_contents .cke_dialog_page_contents tbody:first').children('tr:eq(3)').find('input:eq(3)').val('5');
                $('.cke_dialog_contents .cke_dialog_page_contents tbody:first').children('tr:eq(3)').find('input:eq(4)').val('10');
            }, function (data) {
                var expected = /<img alt="" src="foobar.png" style="margin: 10px 5px; ?" \/>/;

                QUnit.ok(
                    data.search(expected) > -1,
                    'margin attribute set correctly'
                );

                done();
            });
        }, function (done) {
            cke_test.call(this, function () {
                $('#' + $('.cke_required').filter('label:contains(URL)').attr('for')).val('foobar.png');
                $('.cke_dialog_contents .cke_dialog_page_contents tbody:first').children('tr:eq(3)').find('select')[0].selectedIndex = 2;
            }, function (data) {
                var expected = /<img alt="" src="foobar.png" style="float: right; ?" \/>/;

                QUnit.ok(
                    data.search(expected) > -1,
                    'align attribute set correctly'
                );

                done();
            });
        }, function () {
            QUnit.start();
        });

    });
});