/**
 * Manages visibility of apps.
 *
 * The .appstoreUiAppstore() iterates over an app category list and register click events on "show more" links. These links can be used to toggle the visibility of more apps.
 *
 * ### Examples
 * Binds the appstoreUiAppstore() functionality to an app store list.
 *
 * HTML:
 * <div class="ep-appstore">
 *  <section class="ep-appstore-section ep-appstore-section-shipping">
 *    <div class="ep-appstore-section-header ep-flex ep-flex-justify-between ep-flex-align-center">
 *      <h3>Versand</h3>
 *    </div>
 *    <ul class="ep-appstore-list ep-flex ep-flex-wrap ep-flex-justify-between">
 *      <li class="ep-appstore-list-item">
 *        <div class="ep-apps-card">
 *          <div class="ep-apps-card-panel ep-flex">
 *            <div class="ep-apps-card-panel-logo">
 *              <img src="https://mate.epages.com/attachments/4a9163e31e9ec042df25ce93b00cdc2b31c6b623/store/fill/64/64/9d4ce6ea06bc70270514db829aa9f5c6deb4c3188f393a993417b3998b29/icon.png" alt="">
 *            </div>
 *            <div class="ep-apps-card-panel-main">
 *              <h5 class="ep-apps-card-panel-main-header">SendCloud – Cleverer Versand für Ihren Onlineshop</h5>
 *              <div class="ep-apps-card-panel-main-content">Mit SendCloud sparen Sie Zeit und Geld beim Versand</div>
 *            </div>
 *          </div>
 *          <div class="ep-apps-card-footer">
 *            <a class="ep-button ep-button-cta ep-apps-card-button" href="?ViewAction=MBO-ViewAppDetails&amp;appID=3863FC2A-9DAD-4FC1-9448-ED5055E4338D&amp;ObjectID=21060" title="SendCloud – Cleverer Versand für Ihren Onlineshop">Mehr erfahren</a>
 *          </div>
 *        </div>
 *      </li>
 *      <li class="ep-appstore-list-item">
 *        <div class="ep-apps-card">
 *          <div class="ep-apps-card-panel ep-flex">
 *            <div class="ep-apps-card-panel-logo">
 *              <img src="https://mate.epages.com/attachments/78ec3af14d3922a4366a98108b49bf604201af65/store/fill/64/64/e4218900832a583e3dfc8dcb5ec95edf8e9e2954fb41ef70626bef17a516/icon.png" alt="">
 *            </div>
 *            <div class="ep-apps-card-panel-main">
 *              <h5 class="ep-apps-card-panel-main-header">Packlink PRO - Simply Shipping</h5>
 *              <div class="ep-apps-card-panel-main-content">Einfach professionell versenden! Mit Multi-Sendungsverfolgung, über 300 Versandservices, Mengenrabatten sowie API- und Shopintegrationen auf einer Plattform.</div>
 *            </div>
 *          </div>
 *          <div class="ep-apps-card-footer">
 *            <a class="ep-button ep-button-cta ep-apps-card-button" href="?ViewAction=MBO-ViewAppDetails&amp;appID=770702F5-2476-43C9-88BF-CC8966DFC1FA&amp;ObjectID=21060" title="Packlink PRO - Simply Shipping">Mehr erfahren</a>
 *          </div>
 *        </div>
 *      </li>
 *    </ul>
 *  </section>
 *
 *  <section class="ep-appstore-section ep-appstore-section-marketing_sales ep-appstore-section-showmore">
 *    <div class="ep-appstore-section-header ep-flex ep-flex-justify-between ep-flex-align-center">
 *      <h3>Marketing &amp; Verkauf</h3>
 *      <a href="" class="ep-appstore-section-showmore-toggle">
 *        {ShowMore}
 *      </a>
 *    </div>
 *    <ul class="ep-appstore-list ep-flex ep-flex-wrap ep-flex-justify-between">
 *      <li class="ep-appstore-list-item">
 *        <div class="ep-apps-card">
 *          <div class="ep-apps-card-panel ep-flex">
 *            <div class="ep-apps-card-panel-logo">
 *              <img src="https://mate.epages.com/attachments/357e257bf77bf5afbbfae0e71e3e976698dd649f/store/fill/64/64/b5b625adbc86e4aa19c1a40972a2d3a8715e12be498f3458971cee593a02/icon.png" alt="">
 *            </div>
 *            <div class="ep-apps-card-panel-main">
 *              <h5 class="ep-apps-card-panel-main-header">Trustami - Ein Siegel für alle Kundenbewertungen</h5>
 *              <div class="ep-apps-card-panel-main-content">Mit dem Trustami Vertrauenssiegel sammeln Sie alle Ihre Bewertungen aus mehr als 25 Quellen.</div>
 *            </div>
 *          </div>
 *          <div class="ep-apps-card-footer">
 *            <a class="ep-button ep-button-cta ep-apps-card-button" href="?ViewAction=MBO-ViewAppDetails&amp;appID=938222F2-2060-4A5D-9822-3D36D4730928&amp;ObjectID=21060" title="Trustami - Ein Siegel für alle Kundenbewertungen">Mehr erfahren</a>
 *          </div>
 *        </div>
 *      </li>
 *      <li class="ep-appstore-list-item">
 *        <div class="ep-apps-card">
 *          <div class="ep-apps-card-panel ep-flex">
 *            <div class="ep-apps-card-panel-logo">
 *              <img src="https://mate.epages.com/attachments/1851bc82a03ad4fb20bda56d7a962d5f9177a2b4/store/fill/64/64/f4069903a56466a8e9eb0bf991d1da14135115a4c032e1f0c6f442cfa4f2/icon.png" alt="">
 *            </div>
 *            <div class="ep-apps-card-panel-main">
 *              <h5 class="ep-apps-card-panel-main-header">Marktfeed</h5>
 *              <div class="ep-apps-card-panel-main-content">Marktfeed, an official API partner of Marktplaats.nl, is the ideal tool for automatic real-time ad placements on Marktplaats for all shop owners.</div>
 *            </div>
 *          </div>
 *          <div class="ep-apps-card-footer">
 *            <a class="ep-button ep-button-cta ep-apps-card-button" href="?ViewAction=MBO-ViewAppDetails&amp;appID=C1B03F81-FEED-4BF6-A801-C2DDDE0AC857&amp;ObjectID=21060" title="Marktfeed">Mehr erfahren</a>
 *          </div>
 *        </div>
 *      </li>
 *
 *      <li class="ep-appstore-list-item ep-appstore-list-item-hidden HideElement">
 *        <div class="ep-apps-card">
 *          <div class="ep-apps-card-panel ep-flex">
 *            <div class="ep-apps-card-panel-logo">
 *              <img src="https://mate.epages.com/attachments/20f7401eab756149ba5c624fa12a1c7095267a34/store/fill/64/64/f11f2b245aef2bc5c641940c2fdc5d221d83370fe4eaa1dd113ed1bd8a65/icon.png" alt="">
 *            </div>
 *            <div class="ep-apps-card-panel-main">
 *              <h5 class="ep-apps-card-panel-main-header">CleverReach® E-Mail Marketing</h5>
 *              <div class="ep-apps-card-panel-main-content">Gezieltes E-Mail-Marketing für mehr Umsatz in Ihrem Onlineshop</div>
 *            </div>
 *          </div>
 *          <div class="ep-apps-card-footer">
 *            <a class="ep-button ep-button-cta ep-apps-card-button" href="?ViewAction=MBO-ViewAppDetails&amp;appID=8F671B9E-FEA2-4F44-9C51-B4473EE107C9&amp;ObjectID=21060" title="CleverReach® E-Mail Marketing">Mehr erfahren</a>
 *          </div>
 *        </div>
 *      </li>
 *      <li class="ep-appstore-list-item ep-appstore-list-item-hidden HideElement">
 *        <div class="ep-apps-card">
 *          <div class="ep-apps-card-panel ep-flex">
 *            <div class="ep-apps-card-panel-logo">
 *              <img src="https://mate.epages.com/attachments/a93797fcf2854e93430e36880a02562359384a52/store/fill/64/64/05aa5be5634ec7e7cea6e872ea1c67e3815824008145f4627085771ce0d2/icon.png" alt="">
 *            </div>
 *            <div class="ep-apps-card-panel-main">
 *              <h5 class="ep-apps-card-panel-main-header">flour.io</h5>
 *              <div class="ep-apps-card-panel-main-content">flour.io ist eine webbasierte Kassenlösung für Ihren Onlineshop – jetzt kostenlos testen!</div>
 *            </div>
 *          </div>
 *          <div class="ep-apps-card-footer">
 *            <a class="ep-button ep-button-cta ep-apps-card-button" href="?ViewAction=MBO-ViewAppDetails&amp;appID=D5FA027F-4162-4542-9779-55C41E058F23&amp;ObjectID=21060" title="flour.io">Mehr erfahren</a>
 *          </div>
 *        </div>
 *      </li>
 *    </ul>
 *  </section>
 * </div>
 *
 * JavaScript:
 *
 * <script>
 *    require([
 *      'jquery',
 *      'ep',
 *
 *      'de_epages/appstore/ui/appstore',
 *      '$ready!'
 *    ], function($, ep) {
 *      var appStore = ep('.ep-appstore');
 *
 *      appStore.appstoreUiAppstore({
 *        translations: {
 *          hideButton: '{HideMore}',
 *          showButton: '{ShowMore}'
 *        }
 *      });
 *    });
 * </script>
 *
 *
 *
 * @class jQuery.ui.appstoreUiAppstore
 * @extends jQuery.widget
 *
 * @uses ep
 * @uses de_epages
 * @uses ep.dict
 * @uses jQuery.ui.widget
 * @uses de_epages/appstore/ui/appstore
 * @since 7.38.0
 */

/**
 * @cfg {Object} [translations] Translations for the the states (toggle more/less) of the toggle links.
 */

/**
 * See `jQuery.ui.appstoreUiAppstore` for details.
 *
 * @param {Object} [translations] Translations for the the states (toggle more/less) of the toggle links.
 *
 *
 * @method appstoreUiAppstore
 * @member jQuery
 *
 * @since 7.38.0
 */

/*
 * @copyright       © Copyright 2006-2019, epages GmbH, All Rights Reserved.
 *
 * @module          de_epages/appstore/ui/appstore
 */

define("de_epages/appstore/ui/appstore", [
    "jquery",
    "ep",
    "de_epages",
    "$dict!de_epages/appstore/dictionary",

    "jquery/ui/widget"
], function($, ep, de_epages, epDict) {
/*
 * @dictionary      de_epages.appstore.dictionary
 *
 * @translation     {HideMore}
 *                  {ShowMore}
 */

    $.widget('ui.appstoreUiAppstore', {
        // toggleSections,

        options: {
            translations: {
                hideButton: epDict.translate('HideMore'),
                showButton: epDict.translate('ShowMore')
            }
        },

        /**
          * Method is called during initialization, when widget is created.
          *
          * @member jQuery.ui.appstoreUiAppstore
          *
          * @since 7.38.0
          **/
        _create: function() {
            var self = this,
                elem = self.element;

            self.toggleSections = elem.children('.ep-appstore-section-showmore');

            self.toggleSections.each(function(index, section) {
                var $section = $(section);

                // register click event for "show more" links
                $section.find('.ep-appstore-section-showmore-toggle').on(
                    'click.toggleVisibility',
                    {
                        self: self,
                        section: $section
                    },
                    function(evt) {
                        self._toggleVisibility(evt)
                    }
                );
            });
        },

        /**
          * Toggle visibility of app items.
          *
          * @member jQuery.ui.appstoreUiAppstore
          *
          * @since 7.38.0
          *
          **/
        _toggleVisibility: function(evt) {
            var self = evt.data.self,
                o = self.options,
                linkText = o.translations.showButton,
                section = evt.data.section;

            evt.preventDefault();

            // set state (show/hide)
            section.data('open', !section.data('open'));
            section.find('.ep-appstore-list-item-hidden').toggleClass('HideElement');

            // scroll to top, if visibility set visible
            if (section.data('open')) {
                // change link text
                linkText = o.translations.hideButton;

                // scroll smooth to top
                window.scrollTo({
                    top: (section.offset().top - 70),
                    left: 0,
                    behavior: 'smooth'
                });
            }

            // set associated link text
            $(evt.target).html(linkText);
        },

        /**
          * Method to clean up DOM and elements.
          *
          * @member jQuery.ui.appstoreUiAppstore
          *
          * @since 7.38.0
          **/
        destroy: function() {
            var self = this;

            // remove click events from "show more" links
            self.toggleSections.each(function(index, section) {
                $(section).find('.ep-appstore-section-showmore-toggle').off('click.toggleVisibility');
            });

            this._superApply(arguments);
        }
    });

    return de_epages;
});


