/*global define window*/
/*jslint browser:true*/
define([
     'testsuite/qunit',
     'testsuite/qunit-fixture!de_epages/product/ui/variationwizard-unity-test.html',
     'de_epages/product/ui/variationwizard-unity-test-helper',
     'jquery',
     'de_epages/product/ui/variationattribute-unity',
     'de_epages/product/ui/variationwizard-unity',
     'ep',

     'jquery/metaparse',
     '$ready!'
], function (QUnit, fixture1, helper, $, de_epages, ep) {
        'use strict';

    // overwrite default timeout
    window.timeoutOverwrite = 60;

    var bus = $('div'),
        options = {
            input: '.ep-variationassistant-attributevalueinput',
            initialInput: '.ep-variationassistant-attributevalueinput-initial',
            list: '.ep-variationassistant-attributelist',
            bus: $('.ep-variationassistant-attributelist').closest('form')
        },
        values;

    QUnit.module("de_epages/product/ui/variationwizard-unity'");

    QUnit.asyncTest("widget test presence of methods", function () {
        $.each([
            '_create',
            '_handleProductTypeSwitch',
            '_handleProductTypeAliasInput',
            '_deleteAttribute',
            '_toggleAttributeUsage',
            '_newAttribute',
            '_validateAttributeCount',
            '_validateAttributeAliases',
            '_validateSingleAttribute',
            '_validateAttributes',
            '_checkForUnassignedAttributes',
            '_getUnassignedAttributes',
            '_getSelectedAttributes',
            '_generateAttributeAssignmentTable',
            '_generateSingleAttributeAssingement',
            '_validateDefaultSelection',
            '_getDefaultValues',
            '_generateVariationList',
            '_generateNewProducts',
            '_validateNewVariations',
            '_findDuplicateVariationAlias',
            '_findEmptyVariationAlias',
            '_getSelectedVariations',
            '_handleNext',
            '_handleBack',
            '_handleSubmit',
            '_delay',
            'destroy'
        ], function (i, fn) {
               QUnit.equal(
                $.isFunction($.ui.productUiVariationwizardUnity.prototype[fn]),
                true,
                '$.isFunction(' + fn + '):'
            );
        });

        QUnit.start();
    });

    QUnit.asyncTest("basic test", function () {
        fixture1.init();

        var h = helper();

        window.setTimeout(function() {
            $('#Alias').val('test123').trigger('input');

            window.setTimeout(function() {
                QUnit.ok(!$('#EnterNewAttributeButton').closest('.row').hasClass('HideElement'), 'New Attribute button is shown once product type name was entered.');
                QUnit.ok(!$('.ep-step2-wrapper').hasClass('HideElement'), 'Attribute input area is shown once product type name was entered.');
                QUnit.equal($('#AttributeContainerAttributeHeadline').html(), 'test123', 'Attribute area headline was set to new attribute name.');

                h.addAttribute()(function() {
                h.addAttribute()(function() {


                h.setAlias(0, 'Attribute0')(function() {
                h.testButtons({next: [0,1]});

                h.setValue(0, 0, 'value0')(function() {
                    h.testButtons({next: [1,1]});

                    h.addValue(0, 'value1')(function() {
                    h.setAlias(1, 'Attribute1')(function() {
                    h.setValue(1, 0, 'value0')(function() {
                    h.addValue(1, 'value1')(function() {
                        h.testButtons({next: [1,1]});

                        h.nextStep()(function() {
                            h.testAliases(4);
                            h.testButtons({back: [1,1], finish: [1,1]});

                            h.lastStep()(function() {
                                h.testButtons({next: [1,1]});

                                h.addValue(0, 'value2')(function() {
                                h.addValue(0, 'value3')(function() {
                                h.addValue(1, 'value2')(function() {
                                h.addValue(1, 'value3')(function() {
                                h.nextStep()(function() {
                                    h.testAliases(16);

                                    fixture1.destroy();
                                    QUnit.start();
                                });
                                });
                                });
                                });
                                });
                            });
                        });
                    });
                    });
                    });
                    });
                });
                });

                });
                });
            }, 300);
        }, 1000);
    });

    QUnit.asyncTest("test attribute count", function () {
        fixture1.init();

        var h = helper();

        window.setTimeout(function() {
            $('#Alias').val('test123').trigger('input');

            window.setTimeout(function() {
                QUnit.ok(!$('#EnterNewAttributeButton').closest('.row').hasClass('HideElement'), 'New Attribute button is visible.');

                h.addAttribute()(function() {
                h.addAttribute()(function() {
                h.addAttribute()(function() {

                    QUnit.ok($('#EnterNewAttributeButton').closest('.row').hasClass('HideElement'), 'New Attribute button is hidden once max value is reached');

                    h.setAlias(0, 'Attribute0')(function() {
                    h.setAlias(1, 'Attribute1')(function() {
                    h.setAlias(2, 'Attribute2')(function() {

                    h.setValue(0, 0, 'value0')(function() {
                    h.setValue(1, 0, 'value0')(function() {
                    h.setValue(2, 0, 'value0')(function() {

                        h.testButtons({next: [1,1]});

                        h.deleteAttribute(1)(function() {
                            QUnit.ok(!$('#EnterNewAttributeButton').closest('.row').hasClass('HideElement'), 'New Attribute button is visible after deleting attribute.');
                            QUnit.ok(h.getAlias(0) ===  'Attribute0' && h.getAlias(1) ===  'Attribute2', '2nd attribute was deleted');

                            h.deleteAttribute(0)(function() {
                            h.deleteAttribute(0)(function() {
                                QUnit.ok(!$('#NoAttributes').hasClass('HideElement'), 'no attribute warning shown');
                                h.testButtons({next: [0,1]});

                                fixture1.destroy();
                                QUnit.start();
                            });
                            });
                        });

                    });
                    });
                    });

                    });
                    });
                    });

                });
                });
                });
            }, 300);
        }, 1000);
    });

    QUnit.asyncTest("test alias validation", function () {
        fixture1.init();

        var h = helper();

        window.setTimeout(function() {
            $('#Alias').val('test123').trigger('input');

            window.setTimeout(function() {
                QUnit.ok(!$('#EnterNewAttributeButton').closest('.row').hasClass('HideElement'), 'New Attribute button is visible.');

                h.addAttribute()(function() {
                h.addAttribute()(function() {
                h.addAttribute()(function() {

                    h.setAlias(0, 'Attribute0')(function() {
                    h.setValue(0, 0, 'value0')(function() {

                        h.testButtons({next: [1,1]});
                        QUnit.ok(!$('.ui-invalid').length, 'no error existing');

                        h.setAlias(1, 'Attribute0')(function() {
                        h.setValue(1, 0, 'value0')(function() {
                            h.testButtons({next: [0,1]});
                            QUnit.equal($('.ui-invalid').length, 2, 'two errors found');

                            h.setAlias(2, 'Attribute0')(function() {
                            h.setValue(2, 0, 'value0')(function() {

                                h.testButtons({next: [0,1]});
                                QUnit.equal($('.ui-invalid').length, 3, 'three errors found');

                                h.setAlias(2, 'Attribute2')(function() {
                                h.setAlias(1, 'Attribute1')(function() {

                                    h.testButtons({next: [1,1]});
                                    QUnit.equal($('.ui-invalid').length, 0, 'no errors found');

                                    fixture1.destroy();
                                    QUnit.start();
                                });
                                });
                            });
                            });

                        });
                        });

                    });
                    });

                });
                });
                });
            }, 300);
        }, 1000);
    });

    QUnit.asyncTest("combination error test", function () {
        fixture1.init();

        var h = helper();

        window.setTimeout(function() {
            $('#Alias').val('test123').trigger('input');

            window.setTimeout(function() {
                h.addAttribute()(function() {
                h.addAttribute()(function() {
                h.addAttribute()(function() {

                    h.setAlias(0, 'Attribute0')(function() {
                    h.setValue(0, 0, 'value0')(function() {
                    h.addValue(0, 'value1')(function() {
                    h.addValue(0, 'value2')(function() {
                    h.addValue(0, 'value3')(function() {

                        h.testButtons({next: [1,1]});
                        QUnit.ok(!$('.ui-invalid').length, 'no error existing');

                        h.setAlias(1, 'Attribute0')(function() {
                        h.setValue(1, 0, 'value0')(function() {
                        h.addValue(1, 'value0')(function() {
                        h.addValue(1, 'value0')(function() {

                            h.testButtons({next: [0,1]});
                            QUnit.equal($('.ui-invalid').length, 5, 'five errors found');

                            h.setValue(0, 1, 'value0')(function() {
                            h.setValue(1, 1, 'value1')(function() {

                                QUnit.equal($('.ui-invalid').length, 6, 'six errors found');
                                h.setAlias(1, 'Attribute1')(function() {

                                    QUnit.equal($('.ui-invalid').length, 4, 'four errors found');
                                    h.setValue(0, 0, 'value1')(function() {
                                    h.setValue(1, 1, 'value1')(function() {
                                    h.setValue(1, 2, 'value2')(function() {
                                        h.testButtons({next: [1,1]});
                                        QUnit.ok(!$('.ui-invalid').length, 'no error existing');

                                        fixture1.destroy();
                                        QUnit.start();
                                    });
                                    });
                                    });
                                });
                            });
                            });

                        });
                        });
                        });
                        });

                    });
                    });
                    });
                    });
                    });

                });
                });
                });
            }, 300);
        }, 1000);
    });

});