/*globals define, window*/

define([
    'testsuite/qunit',
    'testsuite/qunit-fixture!ep/ui/lightbox-test',
    'jquery',

    'ep/ui/lightbox',
    '$ready!'
], function (QUnit, fixture, $, ep) {

    QUnit.module("ep/ui/lightbox", {
        setup: fixture.init,
        teardown: fixture.destroy
    });

    QUnit.asyncTest("ep/ui/lightbox", function () {

        var t,

            init = ep('#images')
                .uiLightbox({
                    images          : '#images img',
                    controls        : 'visible',
                    caption         : true,
                    count           : true,
                    thumbs          : true,
                    closeOnEscape   : true,
                    closeOnClickOut : true
                })
                .find('img:first')
                .trigger('click')
                .end(),

            imgData = ep.ui.imgData('#images img')
                .on('lightbox', function () {
                    t = this.current();
                }),

            light01 = ep('.ep-uiLightbox');

        setTimeout(function () {

            QUnit.equal(
                light01.hasClass('ui-hidden'),
                false,
                "ep('.ep-uiLightbox').hasClass('ui-hidden'))"
            );

            QUnit.equal(
                light01.find('img').length,
                9,
                "ep('.ep-uiLightbox').length"
            );

            QUnit.equal(
                imgData.current().desc,
                "Bild 1",
                "ep.ui.imgData('#images img').current().desc"
            );

            QUnit.equal(
                imgData.current().src,
                "../ep/ui/lightbox-test-image1.jpg",
                "ep.ui.imgData('#images img').current().src"
            );

            QUnit.equal(
                light01.find('img').attr('src'),
                "../ep/ui/lightbox-test-image1.jpg",
                "ep('.ep-uiLightbox img').attr('src')"
            );

            var beforeWidth = light01.width(),
                beforeHeight = light01.height();
            $(window).trigger('resize');

            setTimeout(function () {

                var afterWidth = light01.width(),
                    afterHeight = light01.height();

                QUnit.equal(
                    afterWidth === beforeWidth || afterWidth === beforeWidth - 20,
                    true,
                    "ep('.ep-uiLightbox').width() == .width() // window resize"
                );

                QUnit.equal(
                    afterHeight === beforeHeight || afterHeight === beforeHeight - 20,
                    true,
                    "ep('.ep-uiLightbox').height() == .height() // window resize"
                );

                light01.find('.ep-uiLightbox-ctrlClose').trigger('click');

                QUnit.equal(
                    light01.hasClass('ui-hidden'),
                    true,
                    "ep('.ep-uiLightbox').hasClass('ui-hidden')"
                );

                init.uiLightbox('destroy');

                QUnit.start();

            }, 500);

        }, 500);

    });
});